@@ -1,5 +1,3 @@
-// Package v1alpha1 implements all the required types and methods for parsing
-// resources for v1alpha1 versioned ClusterServiceVersions.
 package v1alpha1
 
 import (
@@ -50,6 +48,7 @@ type NamedInstallStrategy struct {
 }
 
 // StatusDescriptor describes a field in a status block of a CRD so that OLM can consume it
+// +k8s:openapi-gen=true
 type StatusDescriptor struct {
 	Path         string           `json:"path"`
 	DisplayName  string           `json:"displayName,omitempty"`
@@ -59,6 +58,7 @@ type StatusDescriptor struct {
 }
 
 // SpecDescriptor describes a field in a spec block of a CRD so that OLM can consume it
+// +k8s:openapi-gen=true
 type SpecDescriptor struct {
 	Path         string           `json:"path"`
 	DisplayName  string           `json:"displayName,omitempty"`
@@ -68,6 +68,7 @@ type SpecDescriptor struct {
 }
 
 // ActionDescriptor describes a declarative action that can be performed on a custom resource instance
+// +k8s:openapi-gen=true
 type ActionDescriptor struct {
 	Path         string           `json:"path"`
 	DisplayName  string           `json:"displayName,omitempty"`
@@ -77,6 +78,7 @@ type ActionDescriptor struct {
 }
 
 // CRDDescription provides details to OLM about the CRDs
+// +k8s:openapi-gen=true
 type CRDDescription struct {
 	Name              string                 `json:"name"`
 	Version           string                 `json:"version"`
@@ -90,6 +92,7 @@ type CRDDescription struct {
 }
 
 // APIServiceDescription provides details to OLM about apis provided via aggregation
+// +k8s:openapi-gen=true
 type APIServiceDescription struct {
 	Name              string                 `json:"name"`
 	Group             string                 `json:"group"`
@@ -106,6 +109,7 @@ type APIServiceDescription struct {
 }
 
 // APIResourceReference is a Kubernetes resource type used by a custom resource
+// +k8s:openapi-gen=true
 type APIResourceReference struct {
 	Name    string `json:"name"`
 	Kind    string `json:"kind"`
@@ -121,6 +125,7 @@ func (d APIServiceDescription) GetName() string {
 // an operator being ran by ClusterServiceVersion.
 //
 // If the CRD is present in the Owned list, it is implicitly required.
+// +k8s:openapi-gen=true
 type CustomResourceDefinitions struct {
 	Owned    []CRDDescription `json:"owned,omitempty"`
 	Required []CRDDescription `json:"required,omitempty"`
@@ -128,6 +133,7 @@ type CustomResourceDefinitions struct {
 
 // APIServiceDefinitions declares all of the extension apis managed or required by
 // an operator being ran by ClusterServiceVersion.
+// +k8s:openapi-gen=true
 type APIServiceDefinitions struct {
 	Owned    []APIServiceDescription `json:"owned,omitempty"`
 	Required []APIServiceDescription `json:"required,omitempty"`
@@ -225,6 +231,7 @@ const (
 	CSVReasonRequirementsMet                             ConditionReason = "AllRequirementsMet"
 	CSVReasonOwnerConflict                               ConditionReason = "OwnerConflict"
 	CSVReasonComponentFailed                             ConditionReason = "InstallComponentFailed"
+	CSVReasonComponentFailedNoRetry                      ConditionReason = "InstallComponentFailedNoRetry"
 	CSVReasonInvalidStrategy                             ConditionReason = "InvalidInstallStrategy"
 	CSVReasonWaiting                                     ConditionReason = "InstallWaiting"
 	CSVReasonInstallSuccessful                           ConditionReason = "InstallSucceeded"
@@ -245,6 +252,7 @@ const (
 	CSVReasonTooManyOperatorGroups                       ConditionReason = "TooManyOperatorGroups"
 	CSVReasonInterOperatorGroupOwnerConflict             ConditionReason = "InterOperatorGroupOwnerConflict"
 	CSVReasonCannotModifyStaticOperatorGroupProvidedAPIs ConditionReason = "CannotModifyStaticOperatorGroupProvidedAPIs"
+	CSVReasonDetectedClusterChange                       ConditionReason = "DetectedClusterChange"
 )
 
 // Conditions appear in the status as a record of state transitions on the ClusterServiceVersion
@@ -353,9 +361,10 @@ type ClusterServiceVersionStatus struct {
 	CertsRotateAt metav1.Time `json:"certsRotateAt,omitempty"`
 }
 
-// ClusterServiceVersion is a Custom Resource of type `ClusterServiceVersionSpec`.
 // +k8s:deepcopy-gen:interfaces=k8s.io/apimachinery/pkg/runtime.Object
 // +genclient
+
+// ClusterServiceVersion is a Custom Resource of type `ClusterServiceVersionSpec`.
 type ClusterServiceVersion struct {
 	metav1.TypeMeta   `json:",inline"`
 	metav1.ObjectMeta `json:"metadata"`
@@ -364,8 +373,9 @@ type ClusterServiceVersion struct {
 	Status ClusterServiceVersionStatus `json:"status"`
 }
 
-// ClusterServiceVersionList represents a list of ClusterServiceVersions.
 // +k8s:deepcopy-gen:interfaces=k8s.io/apimachinery/pkg/runtime.Object
+
+// ClusterServiceVersionList represents a list of ClusterServiceVersions.
 type ClusterServiceVersionList struct {
 	metav1.TypeMeta `json:",inline"`
 	metav1.ListMeta `json:"metadata"`
